@@ -35,3 +35,17 @@ plotb <- bquote_function(graphics::plot)
 plotb(x = .(variable), 
       y = sin(.(variable)))
 
+## ------------------------------------------------------------------------
+f <- function() { 
+  sin
+}
+
+# pipe 5 to the value of f()
+# the .() says to evaluate f() before the
+# piping
+5 %.>% .(f())
+
+# evaluate "f()"" with . = 5
+# not interesting as "f()"" is "dot free" 
+5 %.>% f()
+
